==> sword_1.5.3.orig.tar.gz: sword-1.5.3.orig/apps/windoze/CBuilder5/prototype/sword.cpp <==
//---------------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop
USERES("sword.res");
USEFORM("mainfrm.cpp", Form1);
USELIB("swordlib.lib");
USEFORM("ModInstForm.cpp", ModInstFrm);
USEUNIT("..\..\swdisprtf.cpp");
USEUNIT("..\..\swdisprtfchap.cpp");
USEUNIT("..\..\swwinlog.cpp");
USEUNIT("..\..\tbdisp.cpp");
USEFORM("searchfrm.cpp", Form2);
USEFORM("editentryfrm.cpp", EditEntry);
USEUNIT("biblecsmgr.cpp");
USEFORM("bookmarkfrm.cpp", Bookmarksfrm);
USEFORM("AboutBoxfrm.cpp", AboutBox);
USEFORM("optionfrm.cpp", Optionsfrm);
USEFORM("vrslstfrm.cpp", VerseListFrm);
USEFORM("versesel.cpp", VerseSelFrm);
USEFORM("newbmfilefrm.cpp", NewBMfrm);
USEUNIT("CommentPanel.cpp");
USEUNIT("ModTabPanel.cpp");
USEFORM("AppBar.cpp", AppBarFrm);
USEUNIT("BookMarkPanel.cpp");
USEUNIT("TextPanel.cpp");
USEUNIT("LDPanel.cpp");
USEFORM("DeskTopNameForm.cpp", DeskTopNameFrm);
USEFORM("DockCanvas.cpp", DockCanvasFrm);
//---------------------------------------------------------------------------
WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
{
	try
	{
		Application->Initialize();
		Application->CreateForm(__classid(TAppBarFrm), &AppBarFrm);
		Application->CreateForm(__classid(TDeskTopNameFrm), &DeskTopNameFrm);
		Application->CreateForm(__classid(TDockCanvasFrm), &DockCanvasFrm);
		Application->Run();
	}
	catch (Exception &exception)
	{
		Application->ShowException(&exception);
	}
	return 0;
}
//---------------------------------------------------------------------------

==> sword-1.5.5.tar.gz: sword-1.5.5/apps/windoze/CBuilder5/prototype/sword.cpp <==
//---------------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop
USERES("sword.res");
USEFORM("mainfrm.cpp", Form1);
USEFORM("ModInstForm.cpp", ModInstFrm);
USEUNIT("..\..\swdisprtf.cpp");
USEUNIT("..\..\swdisprtfchap.cpp");
USEUNIT("..\..\swwinlog.cpp");
USEUNIT("..\..\tbdisp.cpp");
USEFORM("searchfrm.cpp", Form2);
USEFORM("editentryfrm.cpp", EditEntry);
USEUNIT("biblecsmgr.cpp");
USEFORM("bookmarkfrm.cpp", Bookmarksfrm);
USEFORM("AboutBoxfrm.cpp", AboutBox);
USEFORM("optionfrm.cpp", Optionsfrm);
USEFORM("vrslstfrm.cpp", VerseListFrm);
USEFORM("versesel.cpp", VerseSelFrm);
USEFORM("newbmfilefrm.cpp", NewBMfrm);
USEUNIT("CommentPanel.cpp");
USEUNIT("ModTabPanel.cpp");
USEFORM("AppBar.cpp", AppBarFrm);
USEUNIT("BookMarkPanel.cpp");
USEUNIT("TextPanel.cpp");
USEUNIT("LDPanel.cpp");
USEFORM("DeskTopNameForm.cpp", DeskTopNameFrm);
USEFORM("DockCanvas.cpp", DockCanvasFrm);
USEUNIT("..\BibleCS\RxRichEditX.cpp");
USEOBJ("..\BibleCS\rxlib\Vclutils.obj");
USEOBJ("..\BibleCS\rxlib\Rxcconst.obj");
USEOBJ("..\BibleCS\rxlib\Rxcombos.obj");
USEOBJ("..\BibleCS\rxlib\Rxconst.obj");
USEOBJ("..\BibleCS\rxlib\RxRichEd.obj");
USEOBJ("..\BibleCS\rxlib\Maxmin.obj");
USELIB("..\..\..\..\lib\swordlib.lib");
USELIB("..\..\..\..\..\icu-sword\as_is\borland\icui18n.lib");
USELIB("..\..\..\..\..\icu-sword\as_is\borland\icudatab.lib");
USELIB("..\..\..\..\..\icu-sword\as_is\borland\icucommon.lib");
USEOBJ("..\BibleCS\TntUnicodeControls\Unicode.obj");
USEOBJ("..\BibleCS\TntUnicodeControls\TntControls.obj");
USEOBJ("..\BibleCS\TntUnicodeControls\TntForms.obj");
USEOBJ("..\BibleCS\TntUnicodeControls\TntStdCtrls.obj");
USEOBJ("..\BibleCS\TntUnicodeControls\TntClasses.obj");
//---------------------------------------------------------------------------
WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
{
	try
	{
		Application->Initialize();
		Application->CreateForm(__classid(TAppBarFrm), &AppBarFrm);
		Application->CreateForm(__classid(TDeskTopNameFrm), &DeskTopNameFrm);
		Application->CreateForm(__classid(TDockCanvasFrm), &DockCanvasFrm);
		Application->Run();
	}
	catch (Exception &exception)
	{
		Application->ShowException(&exception);
	}
	return 0;
}
//---------------------------------------------------------------------------
